Module core_dockpack::cache
source · Expand description
Defines all the paths to cache directories and also handles the wiping of cache.
Functions
- Processes the image name into a directory name.
- Wipes the cache directory and creates a new cache directory.