This module contains the function to execute the push command to push a docker image to the docker registry.
Functions
- Executes the push command to push a docker image to the docker registry.
This module contains the function to execute the push command to push a docker image to the docker registry.