Module core_dockpack::docker_commands
source · Expand description
Defines the actions around downloading and unpacking docker images to access the files.
Functions
- Pulls a docker image from the docker registry.
- Extracts the Tar file from the Docker image, and saves it to the specified path.