Module cache

Module cache 

Defines all the paths to cache directories and also handles the wiping of cache.

Functions

process_image_name
Processes the image name into a directory name.
wipe_and_create_cache
Wipes the cache directory and creates a new cache directory.