Defines the actions around downloading and unpacking docker images to access the files.
Functions
- build_
docker_ image - Builds a Docker image from a given build context directory.
- pull_
docker_ image - Pulls a docker image from the docker registry.
- push_
docker_ image - Pushes a Docker image to the Docker registry.
- save_
docker_ image - Extracts the Tar file from the Docker image, and saves it to the specified path.