save_docker_image

Function save_docker_image 

pub fn save_docker_image(
    image_name: &str,
    tar_path: &str,
) -> Result<String, String>
Extracts the Tar file from the Docker image, and saves it to the specified path.

Notes

The pulling of the Docker image is also handled in this function.

Arguments

  • image_name - The name of the Docker image to pull and unpack.
  • tar_path - The path to save the unpacked Docker image.

Returns

The path to where the compressed Docker image files are stored