Crate core_dockpack
source ·Expand description
Basic lib for unpacking files from a Docker image.
Modules
- Defines all the paths to cache directories and also handles the wiping of cache.
- Defines the actions around downloading and unpacking docker images to access the files.
- Defines the actions around unpacking compressed Docker files from the manifest.