Module core_dockpack::cmd_processes::pull
source · Expand description
We need the following
pull the docker image create a directory nest a tar in that directory unpack the tar one directory out
Modules
- The API for unpacking Docker images into a directory.