Creates a docker image from a given build context directory.
Modules
- This module contains the function to execute the push command to push a docker image to the docker registry.
Creates a docker image from a given build context directory.