Module core_dockpack::utils

source ·
Basic utils that do not have a specific category yet.

Modules

  • Defines all the paths to cache directories and also handles the wiping of cache.
  • Defines the actions around downloading and unpacking docker images to access the files.
  • Defines the actions around unpacking compressed Docker files from the manifest.