Module docker_commands

Module docker_commands 

Defines the actions around downloading and unpacking docker images to access the files.

Functions

build_docker_image
Builds a Docker image from a given build context directory.
pull_docker_image
Pulls a docker image from the docker registry.
push_docker_image
Pushes a Docker image to the Docker registry.
save_docker_image
Extracts the Tar file from the Docker image, and saves it to the specified path.