Defines the actions around downloading and unpacking docker images to access the files.
Functions
- Builds a Docker image from a given build context directory.
- Pulls a docker image from the docker registry.
- Extracts the Tar file from the Docker image, and saves it to the specified path.